workdir = "~/Documents/Dropbox/work/a_research/russian/russian_compounds/grammaticality_judgments_study/stats/"

chartdir = paste(workdir, "graphs/", sep="")
setwd(workdir)

################################

stimuli1 = read.csv("audio_stimuli_measurements.txt", header=T, sep="")
summary(stimuli1)
colnames(stimuli1)<-c("Filename", "SegmentLabel", "StressLevel", "Theme", "Word", "Duration", "F1", "F2", "F3", "Intensity", "SegPosition")
summary(stimuli1)
unique(stimuli1$SegmentLabel)
stimuli1<-stimuli1[stimuli1$SegmentLabel!="ou", ]
unique(stimuli1$StressLevel)
stimuli1$StressLevel<-factor(stimuli1$StressLevel)
stimuli1$Word<-factor(stimuli1$Word)
unique(stimuli1$Word)
unique(stimuli1$Filename)
stimuli1$Word<-factor(gsub('golovatjap', 'golovotjap', stimuli1$Word))
stimuli1$Word<-factor(gsub('kukurozovod', 'kukuruzovod', stimuli1$Word))
stimuli1$Word<-factor(gsub('snotolkvanije', 'snotolkovanije', stimuli1$Word))
stimuli1$Duration<-1000*stimuli1$Duration
stimuli1$SegmentLabel=factor(gsub('y', 'i', stimuli1$SegmentLabel))

summary(stimuli1)


library(gdata)
ling_predictors<-read.xls("stimuli_ling_predictors.xls")
ling_predictors$Filename<-gsub(".aif @ ::SoundFiles:", "", ling_predictors$sound_file)
ling_predictors$Filename <- factor(ling_predictors$Filename)
ling_predictors$sound_file<-NULL
summary(ling_predictors)

stimuli2<-merge(stimuli1, ling_predictors)

stimuli2$manip<-stimuli2$is_stress_correct
stimuli2$manip <-factor(ifelse(stimuli2$is_stress_correct=="neither" & stimuli2$sec_stress!=0, "w_stress", stimuli2$is_stress_correct))

stimuli2$manip<-gsub("1", "correct", stimuli2$manip)
stimuli2$manip<-gsub("2", "deleted", stimuli2$manip)
stimuli2$manip<-gsub("3", "moved", stimuli2$manip)
stimuli2$manip<-gsub("4", "wo_stress", stimuli2$manip)
stimuli2$manip<-factor(stimuli2$manip)


stimuli2$stem1_length=factor(stimuli2$stem1_length)

stimuli2$word<-stimuli2$Word;stimuli2$Word=NULL

word_predictors<-read.xls("word_ling_predictors.xls")
summary(word_predictors)

stimuli2<-merge(stimuli2, word_predictors)
stimuli2$is_mob_str<-ifelse(stimuli2$stress_type=="mobile" & stimuli2$sec_stress!=0, TRUE, FALSE)
stimuli2$is_fin_str<-ifelse(stimuli2$stress_type=="final" & stimuli2$sec_stress!=0, TRUE, FALSE)
summary(stimuli2)

unique(stimuli2[stimuli2$manip=="correct",]$Filename)
unique(stimuli2[stimuli2$manip=="deleted",]$Filename)
unique(stimuli2[stimuli2$manip=="moved",]$Filename)
unique(stimuli2[stimuli2$manip=="w_stress",]$Filename)
unique(stimuli2[stimuli2$manip=="wo_stress",]$Filename)

rawfreq<-read.xls("raw_freq.xls")
rawfreq<-rawfreq[,c(1, 2)]
colnames(rawfreq)<-c("word", "rawfreq")

stimuli3<-merge(stimuli2, rawfreq)
stimuli3$logfreq<-log(stimuli3$rawfreq)
summary(stimuli3)
stimuli2<-stimuli3

###################################
###################################
###################################
###################################
#Descriptive statistics

StressLevels<-unique(stimuli1$StressLevel)
for(x in StressLevels) {
	print("Duration")
	print(x)
	print(summary(stimuli1[stimuli1$StressLevel==x, ]$Duration))
	print("Standard Deviation")
	print(sd(stimuli1[stimuli1$StressLevel==x, ]$Duration))
	}

stimuli_mid<-subset(stimuli1, SegmentLabel %in% c("e", "o"))
summary(stimuli_mid)

for(x in StressLevels) {
	print("F1")
	print(x)
	print(summary(stimuli_mid[stimuli_mid$StressLevel==x, ]$F1))
	print("Standard Deviation")
	print(sd(stimuli_mid[stimuli_mid$StressLevel==x, ]$F1))
	}
	
for(x in StressLevels) {
	print("F1")
	print(x)
	print(summary(stimuli1[stimuli1$StressLevel==x, ]$F1))
	print("Standard Deviation")
	print(sd(stimuli1[stimuli1$StressLevel==x, ]$F1))
	}


for(x in StressLevels) {
	print("F2")
	print(x)
	print(summary(stimuli1[stimuli1$StressLevel==x, ]$F2))
	print("Standard Deviation")
	print(sd(stimuli1[stimuli1$StressLevel==x, ]$F2))
	}

for(x in StressLevels) {
	print("Intensity")
	print(x)
	print(summary(stimuli1[stimuli1$StressLevel==x, ]$Intensity))
	print("Standard Deviation")
	print(sd(stimuli1[stimuli1$StressLevel==x, ]$Intensity))
	}



#######################################
#######################################
#######################################
#######################################
#######################################

library(languageR)
chartmode = "pdf"
chartmode = "screen"

myfont = "Linux Libertine"; pointsize=12
quartz.fnc = function(cwidth,cheight,cname) {
	if(chartmode=="screen") {
		quartz(width=cwidth,height=cheight)
	}
	if(chartmode=="pdf") {
		quartz(width=cwidth,height=cheight,type="pdf",file=cname)
	}
}
setwd(chartdir)

#######################################
#Charts

#Exploratory charts
hist(stimuli1$Duration)
hist(stimuli1$Intensity)
plot(stimuli2$Duration~stimuli2$logfreq); abline(lm(stimuli2$Duration~stimuli2$logfreq))

#Duration as a function of stress level

sem<-function(x, ...) {sqrt(var(x, ...) / length(x)) }

quartz.fnc(cwidth=5, cheight=5, cname="barplot_duration_by_stress.pdf")
	durmeans<-with(stimuli1, tapply(Duration, list(StressLevel), mean, na.rm=TRUE))
	dursems<-with(stimuli1, tapply(Duration, list(StressLevel), sem, na.rm=TRUE))
	par(family=myfont, ps=pointsize, mar=c(4,4,1,1))
	barplot(durmeans, ylab="Duration (ms)", ylim=c(0, 130))
		x.loc <- c(.7, 1.9, 3.1, 4.3)
	arrows(x.loc, durmeans, x.loc, durmeans+dursems, angle=90, length=.1)
	arrows(x.loc, durmeans, x.loc, durmeans-dursems, angle=90, length=.1)
	abline(h=0)
if (chartmode=="pdf") {dev.off()}

#Intensity as a function of stress level

quartz.fnc(cwidth=5, cheight=5, cname="barplot_intensity_by_stress.pdf")
	intmeans<-with(stimuli1, tapply(Intensity, list(StressLevel), mean, na.rm=TRUE))
	intsems<-with(stimuli1, tapply(Intensity, list(StressLevel), sem, na.rm=TRUE))
	par(family=myfont, ps=pointsize, mar=c(4,4,1,1))
	barplot(intmeans, ylab="Intensity (dB)", ylim=c(70, 87), xpd=FALSE)
	x.loc <- c(.7, 1.9, 3.1, 4.3) 
	arrows(x.loc, intmeans, x.loc, intmeans+intsems, angle=90, length=.1)
	arrows(x.loc, intmeans, x.loc, intmeans-intsems, angle=90, length=.1)
	abline(h=70)
if (chartmode=="pdf") {dev.off()}


#Height as a function of stress level, by vowels

quartz.fnc(cwidth=7, cheight=6, cname="boxplot_f1_by_stress_by_vowel.pdf")
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3), mfrow=c(3,2))
	boxplot(-1*F1~StressLevel,  data=subset(stimuli1, SegmentLabel=="i"), ylab="-1*F1", 	main="/i/")
	boxplot(-1*F1~StressLevel,  data=subset(stimuli1, SegmentLabel=="u"), ylab="-1*F1", 	main="/u/")
	boxplot(-1*F1~StressLevel,  data=subset(stimuli1, SegmentLabel=="e"), ylab="-1*F1", 	main="/e/")
	boxplot(-1*F1~StressLevel,  data=subset(stimuli1, SegmentLabel=="o"), ylab="-1*F1", 	main="/o/")
	boxplot(-1*F1~StressLevel,  data=subset(stimuli1, SegmentLabel=="a"), ylab="-1*F1", 	main="/a/")
if (chartmode=="pdf") {dev.off()}

#Backness as a function of stress level, back vowels only
quartz.fnc(cwidth=6, cheight=6, cname="boxplot_f2_by_stress.pdf")
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3))
	boxplot(F2~StressLevel, data=subset(stimuli1, SegmentLabel %in% c("u")), xlab="Stress Level", ylab="F2")
if (chartmode=="pdf") {dev.off()}

#Does the type of stress manipulation affect how the stimuli were pronounced?
#head(stimuli2)

boxplot(Duration~is_stress_correct, data=stimuli2) #a little: words w deleted stress are shorter
boxplot(Intensity~is_stress_correct, data=stimuli2)
boxplot(Duration~manip, data=stimuli2) #a little: words w deleted stress are shorter
boxplot(Intensity~manip, data=stimuli2)


quartz.fnc(cwidth=6, cheight=6, cname="barplot_duration_by_scorrect.pdf")
	durmeans<-with(stimuli2, tapply(Duration, list(is_stress_correct), mean, na.rm=TRUE))
	dursems<-with(stimuli2, tapply(Duration, list(is_stress_correct), sem, na.rm=TRUE))
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3))
	barplot(durmeans, ylab="Duration (ms)", ylim=c(0, 150))
	x.loc <- c(.7, 1.9, 3.1, 4.3)
	arrows(x.loc, durmeans, x.loc, durmeans+dursems, angle=90, length=.1)
	arrows(x.loc, durmeans, x.loc, durmeans-dursems, angle=90, length=.1)
	abline(h=0)
if (chartmode=="pdf") {dev.off()}


quartz.fnc(cwidth=8, cheight=6, cname="barplot_duration_by_smanip.pdf")
	durmeans<-with(stimuli2, tapply(Duration, list(manip), mean, na.rm=TRUE))
	dursems<-with(stimuli2, tapply(Duration, list(manip), sem, na.rm=TRUE))
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3))
	barplot(durmeans, ylab="Duration (ms)", ylim=c(0, 100), xlim=c(0,7))
	x.loc <- c(.7, 1.9, 3.1, 4.3, 5.5) 
	arrows(x.loc, durmeans, x.loc, durmeans+dursems, angle=90, length=.1)
	arrows(x.loc, durmeans, x.loc, durmeans-dursems, angle=90, length=.1)
	abline(h=0)
if (chartmode=="pdf") {dev.off()}

#and for intensity:

quartz.fnc(cwidth=8, cheight=6, cname="barplot_intensity_by_smanip.pdf")
	intmeans<-with(stimuli2, tapply(Intensity, list(manip), mean, na.rm=TRUE))
	intsems<-with(stimuli2, tapply(Intensity, list(manip), sem, na.rm=TRUE))
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3))
	barplot(intmeans, ylab="Intensity (dB)", ylim=c(0, 90))
	x.loc <- c(.7, 1.9, 3.1, 4.3, 5.5)
	arrows(x.loc, intmeans, x.loc, intmeans+intsems, angle=90, length=.1)
	arrows(x.loc, intmeans, x.loc, intmeans-intsems, angle=90, length=.1)
	abline(h=0)
if (chartmode=="pdf") {dev.off()}

#As a function of position in the word

quartz.fnc(cwidth=6, cheight=6, cname="barplot_duration_by_position.pdf")
	durmeans<-with(stimuli2, tapply(Duration, list(SegPosition), mean, na.rm=TRUE))
	dursems<-with(stimuli2, tapply(Duration, list(SegPosition), sem, na.rm=TRUE))
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3))
	barplot(durmeans, ylab="Duration (ms)", ylim=c(0, 150), xlim=c(0,5))
	x.loc <- c(.7, 1.9, 3.1, 4.3, 5.5)
	arrows(x.loc, durmeans, x.loc, durmeans+dursems, angle=90, length=.1)
	arrows(x.loc, durmeans, x.loc, durmeans-dursems, angle=90, length=.1)
	abline(h=0)
if (chartmode=="pdf") {dev.off()}


#######################################
#######################################
############STATS #####################
#######################################
#######################################

#Posthoc analysis of acoustic properties of stimuli
setwd(workdir)
library(lme4)
source("mer-utils.txt"); source("regression-utils.R")
library(multcomp)

#DURATION MODEL

summary(stimuli2)
stimuli2$StressLevel<-relevel(stimuli2$StressLevel, 'unstressed')
stimuli2$is_stress_correct<-relevel(stimuli2$is_stress_correct, 'deleted')
stimuli2$SegPosition<-relevel(stimuli2$SegPosition, 'initial')
stimuli2$manip<-relevel(stimuli2$manip, 'deleted')
stimuli2$stress_type<-relevel(stimuli2$stress_type, 'mobile')
stimuli2$stem1_length<-relevel(stimuli2$stem1_length, '4')

xtabs(~stimuli2$manip + stimuli2$stress_type)
xtabs(~stimuli2$manip + stimuli2$syllcount) #there are more long words among fixed stress stimuli, and more short words among mobile + final word stimuli

dur0.lm<-lm(Duration ~ StressLevel, data=stimuli2)
dur0.glht<-glht(dur0.lm, linfct=mcp(StressLevel='Tukey'))
summary(dur0.glht)
summary(dur0.lm)
anova(dur0.lm)

dur.corr1.lm<-lm(Duration ~ StressLevel + SegmentLabel + SegPosition + syllcount + logfreq +  SegPosition:StressLevel + SegmentLabel:StressLevel + sonority_fall +  stem1_length + manip,  data=stimuli2)

summary(dur.corr1.lm)
anova(dur.corr1.lm)

x<-dur.corr1.lm
summary(x)
dev.new(height=4, width=12)
par(mfrow=c(1,3))

plot(fitted(x), resid(x))
rug(fitted(x)); rug(resid(x), side=4)
qqnorm(resid(x)); qqline(resid(x), col='red', lty=3)

m.mu = mean(resid(x)); m.sd = sd(resid(x))
hist(resid(x), breaks=1000, freq=FALSE, xlim=c(-3, 3))
curve(dnorm(x, m.mu, m.sd), col='red', add=TRUE)

#LMER for duration, with a random intercept for filename:

dur1.lmer<-lmer(Duration ~ StressLevel + SegmentLabel + SegPosition + syllcount + logfreq + sonority_fall + stem1_length + (1|Filename),  data=stimuli2)
summary(dur.lmer)
dur2.lmer<-lmer(Duration ~ StressLevel + SegmentLabel + SegPosition + syllcount + logfreq + sonority_fall + stem1_length + manip + (1|Filename),  data=stimuli2)
anova(dur1.lmer, dur2.lmer)
x<-dur1.lmer
kappa.mer(x); max(vif.mer(x)); maxcorr.mer(x)

dev.new(height=4, width=12)
par(mfrow=c(1,3))

plot(fitted(x), resid(x))
rug(fitted(x)); rug(resid(x), side=4)
qqnorm(resid(x)); qqline(resid(x), col='red', lty=3)

m.mu = mean(resid(x)); m.sd = sd(resid(x))
hist(resid(x), breaks=1000, freq=FALSE, xlim=c(-3, 3))
curve(dnorm(x, m.mu, m.sd), col='red', add=TRUE)


#INTENSITY MODEL

int0.lm<-lm(Intensity~StressLevel, data=stimuli2)
anova(int0.lm)
int0.glht<-glht(int0.lm, linfct=mcp(StressLevel='Tukey'))
summary(int0.glht)

int.corr1.lm<-lm(Intensity ~ StressLevel + SegmentLabel + syllcount + SegPosition + manip, data=stimuli2)
summary(int.corr1.lm)
anova(int.corr1.lm)

x<-int.corr1.lm
dev.new(height=4, width=12)
par(mfrow=c(1,3))

plot(fitted(x), resid(x))
rug(fitted(x)); rug(resid(x), side=4)
qqnorm(resid(x)); qqline(resid(x), col='red', lty=3)

m.mu = mean(resid(x)); m.sd = sd(resid(x))
hist(resid(x), breaks=60, freq=FALSE, xlim=c(-1.5, 1.5))
curve(dnorm(x, m.mu, m.sd), col='red', add=TRUE)


#######################################