#Loading and coding data


#check how often each left stem appeared in compounds BY STRESS SUBTYPE, to see if the splitting is justified. my recollection is that there we recycled fewer stems in some categories than others

workdir = "~/Documents/Dropbox/work/a_research/russian/russian_compounds/grammaticality_judgments_study/stats/"

chartdir = paste(workdir, "graphs/", sep="")
setwd(workdir)

subjects<-read.table("subjects.txt")
exp <- read.csv("compound_ratings_w_fillers.txt", sep="\t")
summary(exp)
summary(subjects)
length(unique(exp$subject))

exp$is.filler=ifelse(factor(substr(exp$sound_file, 1, 1))=="f", TRUE, FALSE)
exp$word=gsub("^[fs]_","", exp$sound_file)
exp$word=factor(gsub("(_[0-9].aif @ ::SoundFiles:)", "", exp$word))
head(exp)
fillers<-subset(exp, is.filler==TRUE)
exp<-subset(exp, is.filler==FALSE)

#filler_predictors<-unique(fillers$sound_file) separating fillers into a diff file for analysis
#write.csv(filler_predictors, file="filler_predictors.csv")

library(gdata)
#word_predictors<- read.xls("word_ling_predictors.xls")
word_predictors<-read.csv('word_ling_predictors.txt', head=T, sep="\t")
summary(word_predictors$stem1)
length(word_predictors$word)/length(unique(word_predictors$stem1)) #1.71
summary(word_predictors$stem2)
length(unique(word_predictors$stem2))
length(word_predictors$word)/length(unique(word_predictors$stem2)) #1.13
xtabs(~ word_predictors$stem1 + word_predictors$stress_type)
head(word_predictors)

#Number of unique stems used in each subcategory that we analyze in the paper (fixed, mobile, final stress stems)

#Fixed stems, plus ratio of left hand stem per compound
length(unique(word_predictors[word_predictors$stress_type=="fixed",]$stem1))
length(unique(word_predictors[word_predictors$stress_type=="fixed",]$word))/length(unique(word_predictors[word_predictors$stress_type=="fixed",]$stem1)) #1.4
length(unique(word_predictors[word_predictors$stress_type=="fixed",]$word))/length(unique(word_predictors[word_predictors$stress_type=="fixed",]$stem2)) #1.09


length(unique(word_predictors[word_predictors$stress_type=="mobile",]$stem1))
length(unique(word_predictors[word_predictors$stress_type=="mobile",]$word))/length(unique(word_predictors[word_predictors$stress_type=="mobile",]$stem1)) #1.8
length(unique(word_predictors[word_predictors$stress_type=="mobile",]$word))/length(unique(word_predictors[word_predictors$stress_type=="mobile",]$stem2)) #1


length(unique(word_predictors[word_predictors$stress_type=="final",]$stem1))
length(unique(word_predictors[word_predictors$stress_type=="final",]$word))/length(unique(word_predictors[word_predictors$stress_type=="final",]$stem1)) #2
length(unique(word_predictors[word_predictors$stress_type=="final",]$word))/length(unique(word_predictors[word_predictors$stress_type=="final",]$stem2)) #1

length(unique(word_predictors[word_predictors$vowelless_root==T,]$stem1))
length(unique(word_predictors[word_predictors$vowelless_root==F & word_predictors$stress_type=='final',]$stem1))

length(unique(word_predictors[word_predictors$vowelless_root==F & word_predictors$stress_type=='final',]$word))/length(unique(word_predictors[word_predictors$vowelless_root==F & word_predictors$stress_type=='final',]$stem1))


exp<-merge(exp, word_predictors)
summary(exp)
head(exp)

stim_predictors<- read.xls("stimuli_ling_predictors.xls")
summary(stim_predictors)
exp<-merge(exp, stim_predictors)
summary(exp)

#filler_predictors<- read.xls("filler_ling_predictors.xls")

exp$X<-NULL; exp$junk<-NULL

#finished preliminary importing. Now adding some aditional predictors: interstress distance, presence of secondary stress

exp$interstress_distance<-ifelse(exp$sec_stress==0, 5, exp$sec_stress+exp$prim_stress-2)
summary(exp$interstress_distance)
summary(exp)

exp$bin_clash<-ifelse(exp$interstress_distance<2, TRUE, FALSE)

#Coding for presence of secondary stress
exp$is_there_sec_stress<-ifelse(exp$sec_stress>0, TRUE, FALSE)

#Making everything logical and fixing spaces and stuff

exp$is_stress_correct<-gsub("correct ", "correct", exp$is_stress_correct)
exp$is_stress_correct<-gsub("deleted ", "deleted", exp$is_stress_correct)
exp$is_stress_correct<-gsub("moved ", "moved", exp$is_stress_correct)
exp$is_stress_correct<-gsub("NA ", "NA", exp$is_stress_correct)
exp$is_stress_correct<-factor(exp$is_stress_correct)
exp$sonority_fall<-gsub("TRUE ", "TRUE", exp$sonority_fall)
exp$sonority_fall<-gsub("FALSE ", "FALSE", exp$sonority_fall)
exp$sonority_fall<-as.logical(exp$sonority_fall)
summary(exp$sonority_fall)

exp$is_stress_moved<-ifelse(exp$is_stress_correct=="moved", TRUE, FALSE)
exp$stress_type2<-exp$stress_type
exp$stress_type2<-ifelse(exp$vowelless_root==TRUE, "vless", exp$stress_type)

exp$stress_type2<-gsub("1", "final", exp$stress_type2)
exp$stress_type2<-gsub("2", "fixed", exp$stress_type2)
exp$stress_type2<-gsub("3", "mobile", exp$stress_type2)
exp$stress_type2<-factor(exp$stress_type2)

summary(exp)

#Adding raw word frequencies. These were taken from Yandex when the exp was run

rawfreq<-read.xls("raw_freq.xls")
rawfreq<-rawfreq[,c(1, 2)]
colnames(rawfreq)<-c("word", "rawfreq")
exp<-merge(exp, rawfreq)
exp$newlogfreq<-log(exp$rawfreq)
summary(exp$newlogfreq)

exp$init_sec_stress<-ifelse(exp$sec_loc==1,TRUE, FALSE)

#exp<-subset(exp, subject!=13)
head(exp)
summary(exp)
length(unique(exp$word))

expfix<-subset(exp, stress_type=="fixed")
expfin<-subset(exp, stress_type=="final")
expmob<-subset(exp, stress_type=="mobile")

expsec<-subset(exp, is_there_sec_stress==TRUE)

summary(expfix)
summary(expfin)
summary(expmob)

expfin$vlesson=ifelse(expfin$sonority_fall==TRUE, "son_fall", expfin$stress_type2)
expfin$vlesson=gsub("1", "long", expfin$vlesson)
expfin$vlesson=gsub("4", "CC-", expfin$vlesson)
expfin$vlesson=gsub("son_fall", "RC-", expfin$vlesson)
expfin$vlesson<-factor(expfin$vlesson);expfin$vlesson<-relevel(expfin$vlesson, "long")
summary(expfin$vlesson)


unique(expfix$word); length(unique(expfix$word))
unique(expfin$word); length(unique(expfin$word))
unique(expmob$word); length(unique(expmob$word))


#Finished loading data


###########################################
###########################################
###########################################
###########################################

#LMERs

setwd(workdir)
library(lme4)
library(arm)
library(languageR)
library(multcomp)
source("mer-utils.txt"); source("regression-utils.R") #custom-defined shortcut functions for lmer analysis (centering predictors, residualizing)


#SECSTRESSSECSTRESSSECSTRESSSECSTRESS
#SECSTRESSSECSTRESSSECSTRESSSECSTRESS
#SECSTRESSSECSTRESSSECSTRESSSECSTRESS
colnames(expsec)
summary(expsec)
expsec<-subset(expsec, is_stress_moved==FALSE)
expsec$stress_type2<-relevel(expsec$stress_type2, "final") 
levels(expsec$stress_type2)

length(unique(expsec$word))/length(unique(expsec$stem1)) #1.71
length(unique(expsec$word))/length(unique(expsec$stem2)) #1.13

#did not converge:
#msec1<-lmer(key~c.(interstress_distance)
#+stress_type2
#+c.(interstress_distance)*stress_type2
#+(1+c.(interstress_distance)+stress_type2|subject)
#+(1+c.(interstress_distance)|word)
#+(1+c.(interstress_distance)|stem1)
#+(1+c.(interstress_distance)|stem2),
#data=expsec)
#x<-msec1

#sort(sapply(ranef(msec1)$subject, sd))
#sort(sapply(ranef(msec1)$word, sd)) #smallest variance, taking this out
#sort(sapply(ranef(msec1)$stem1, sd))
#sort(sapply(ranef(msec1)$stem2, sd))

#also did not converge with just (1|word), or without (1|word), or with (1|stem2)

msec2<-lmer(key~c.(interstress_distance)
+stress_type2
+c.(interstress_distance):stress_type2
+(1+c.(interstress_distance):stress_type2|subject)
+(1+c.(interstress_distance)|stem1)
+(1+c.(interstress_distance)|word), 
data=expsec)


x<-msec2 #2 is it
x; round(2*(1-pt(abs(coef(summary(x))[,3]), Inf)), 4); kappa.mer(x); max(vif.mer(x)); maxcorr.mer(x)

dev.new(height=4, width=12)
par(mfrow=c(1,3))

plot(fitted(x), resid(x))
rug(fitted(x)); rug(resid(x), side=4)
abline(h=c(-2.5, 2.5), col='red', lty=3)

qqnorm(resid(x)); qqline(resid(x), col='red', lty=3)

m.mu = mean(resid(x)); m.sd = sd(resid(x))
hist(resid(x), breaks=60, freq=FALSE, xlim=c(-3, 3))
curve(dnorm(x, m.mu, m.sd), col='red', add=TRUE)

#Checking to see if ranef inclusion is justified

msec2.1<-update(msec2, .~. - (1+c.(interstress_distance)|stem1)); 
anova(msec2,msec2.1)
msec2.2<-update(msec2, .~. - (1+c.(interstress_distance)|word)); 
anova(msec2,msec2.2)
msec2.3<-update(msec2, .~. - (1+c.(interstress_distance):stress_type2|subject)); 
anova(msec2,msec2.3)


#Other model we report in the paper, comparing fixed stress stems to others:

expsec$stress_type2<-relevel(expsec$stress_type2, "fixed")

levels(expsec$stress_type2)

msec3<-lmer(key~c.(interstress_distance)
+stress_type2
+c.(interstress_distance):stress_type2
+(1+c.(interstress_distance):stress_type2|subject)
+(1+c.(interstress_distance)|stem1)
+(1+c.(interstress_distance)|word), 
data=expsec)

x<-msec3
x; round(2*(1-pt(abs(coef(summary(x))[,3]), Inf)), 4); kappa.mer(x); max(vif.mer(x)); maxcorr.mer(x)

#msec4<-lmer(key~c.(interstress_distance)
#+stress_type2
#+c.(interstress_distance)*stress_type2
#+(1|subject)
#+(1+c.(interstress_distance)|stem1)
#+(1|stem2), 
#data=expsec)

xylowess.fnc(jitter(key)~interstress_distance|stress_type2, exp) #looks linear!

#x<-msec4 #fixed vs. others
#x; round(2*(1-pt(abs(coef(summary(x))[,3]), Inf)), 4); kappa.mer(x); max(vif.mer(x)); maxcorr.mer(x)

#sort(sapply(ranef(msec5)$subject, sd))
#sort(sapply(ranef(msec5)$word, sd))
 
x<-msec3
x
levels(expsec$stress_type2)
dev.new(height=4, width=5)
coef.vect<-coef(summary(x))[,1]
sd.vect<-coef(summary(x))[,2]
names<-c("Intercept", "stress dist.", "vless", "fixed", "mobile", "dist:vless", "dist:fixed", "dist:mobile")
coefplot(coef.vect, sd.vect, varnames=names, var.las=2, main="regression estimates")


#Model criticism
#Plotting the residuals
x<-msec3
dev.new(height=4, width=12)
par(mfrow=c(1,3))

plot(fitted(x), resid(x))
rug(fitted(x)); rug(resid(x), side=4)
abline(h=c(-2.5, 2.5), col='red', lty=3)

qqnorm(resid(x)); qqline(resid(x), col='red', lty=3)

m.mu = mean(resid(x)); m.sd = sd(resid(x))
hist(resid(x), breaks=60, freq=FALSE, xlim=c(-3, 3))
curve(dnorm(x, m.mu, m.sd), col='red', add=TRUE)


#Let's compare this now with the binary clash definition of Yoo

expsec$stress_type2<-relevel(expsec$stress_type2, "final")
levels(expsec$stress_type2)

#didn't converge:
#mbinclash1<-lmer(key~
#c.(bin_clash)
#+stress_type2
#+c.(bin_clash)*stress_type2
#+(c.(bin_clash)+stress_type2|subject)
#+(c.(bin_clash)|word)
#+(c.(bin_clash)|stem1)
#+(c.(bin_clash)|stem2),
#data=expsec)

#sort(sapply(ranef(mbinclash1)$subject, sd))
#sort(sapply(ranef(mbinclash1)$stem1, sd))
#sort(sapply(ranef(mbinclash1)$stem2, sd))
#sort(sapply(ranef(mbinclash1)$word, sd)) #taking by-word slope out and keeping the intercept

mbinclash1<-lmer(key~c.(bin_clash)
+stress_type2
+c.(bin_clash):stress_type2
+(1+c.(bin_clash):stress_type2|subject)
+(1+c.(bin_clash)|word)
+(1+c.(bin_clash)|stem1),
 data=expsec)

#Didn't converge:
#mbinclash<-lmer(key~c.(bin_clash)+stress_type2+c.(bin_clash)*stress_type2+(1+c.(bin_clash)*stress_type2|subject)+(1+c.(bin_clash)|word) + (1+c.(bin_clash)|stem1),data=expsec)

x<-mbinclash1
x
round(2*(1-pt(abs(coef(summary(x))[,3]), Inf)), 4)

kappa.mer(x); max(vif.mer(x)); maxcorr.mer(x)

#Model criticism
#Ploting the residuals
dev.new(height=4, width=12)
par(mfrow=c(1,3))

plot(fitted(x), resid(x))
rug(fitted(x)); rug(resid(x), side=4)
abline(h=c(-2.5, 2.5), col='red', lty=3)

qqnorm(resid(x)); qqline(resid(x), col='red', lty=3)

m.mu = mean(resid(x)); m.sd = sd(resid(x))
hist(resid(x), breaks=40, freq=FALSE, xlim=c(-3, 3))
curve(dnorm(x, m.mu, m.sd), col='red', add=TRUE)

mbinclash1.1<-update(mbinclash1, .~. -(1+c.(bin_clash):stress_type2|subject)); 
anova(mbinclash1,mbinclash1.1)
mbinclash1.2<-update(mbinclash1, .~. -(1+c.(bin_clash)|word)); 
anova(mbinclash1, mbinclash1.2)
mbinclash1.3<-update(mbinclash1, .~. -(1+c.(bin_clash)|stem1)); 
anova(mbinclash1, mbinclash1.3)


#just initial stress words.

expini<-subset(exp, sec_loc==1 & is_stress_correct!="moved")

expini$stress_type2<-relevel(expini$stress_type2, "final")
#mini3<-lmer(key~c.(interstress_distance)+(c.(interstress_distance)*stress_type2|subject)+(1|word), data=expini) #didn't converge
mini1<-lmer(key~c.(interstress_distance)+(c.(interstress_distance)+stress_type2|subject)+(1|word) + (1+c.(interstress_distance)|stem1), data=expini)


x<-mini1; x
round(2*(1-pt(abs(coef(summary(x))[,3]), Inf)), 4)
kappa.mer(x); max(vif.mer(x)); maxcorr.mer(x)

mini1.1<-update(mini1, .~. -(c.(interstress_distance)+stress_type2|subject)); 
anova(mini1, mini1.1)
mini1.2<-update(mini1, .~. -(1|word)); 
anova(mini1, mini1.2)
mini1.3<-update(mini1, .~. -(1+c.(interstress_distance)|stem1)); 
anova(mini1, mini1.3)


#and finally, the binary clash model for just the initial stress words

#mini.bin1<-lmer(key~c.(bin_clash) + stress_type2 + c.(bin_clash):stress_type2 + (c.(bin_clash) * stress_type2 | subject) + (1 | word) + (1+c.(bin_clash)|stem1), data=expini) #did not converge

mini.bin1<-lmer(key~c.(bin_clash)+(c.(bin_clash)+stress_type2|subject)+(1|word)+(1+c.(bin_clash)|stem1), data=expini)
mini.bin1
mini.bin2<-update(mini.bin1, .~. - c.(bin_clash)); 
anova(mini.bin1,mini.bin2)


#x<-mini.bin2;x
#round(2*(1-pt(abs(coef(summary(x))[,3]), Inf)), 4)
#kappa.mer(x); max(vif.mer(x)); maxcorr.mer(x)


####################################
####################################
####################################


#FIXEDFIXEDFIXEDFIXEDFIXED
#FIXEDFIXEDFIXEDFIXEDFIXED
#FIXEDFIXEDFIXEDFIXEDFIXED

colnames(expfix)
summary(expfix)

expfix$is_stress_correct<-factor(expfix$is_stress_correct)
expfix$is_stress_correct<-relevel(expfix$is_stress_correct, "deleted")

levels(expfix$is_stress_correct)


#Some descriptive stats

aggregate(key~is_stress_correct, expfix, mean)
aggregate(key~interstress_distance, expfix, mean)

length(unique(expfix[expfix$interstress_distance==0, ]$sound_file))
length(unique(expfix[expfix$interstress_distance==1, ]$sound_file))
length(unique(expfix[expfix$interstress_distance==2, ]$sound_file))
length(unique(expfix[expfix$interstress_distance==2, ]$sound_file))
length(unique(expfix[expfix$interstress_distance==4, ]$sound_file))
length(unique(expfix[expfix$interstress_distance==5, ]$sound_file))

length(unique(expfix$word))/length(unique(expfix$stem1))
length(unique(expfix$word))/length(unique(expfix$stem2))

#mfix<-lmer(key~is_stress_correct+newlogfreq+is_stress_correct:newlogfreq +(is_stress_correct:newlogfreq|subject)+(is_stress_correct|word)+(is_stress_correct*newlogfreq|stem1), data=expfix) didn't converge

#mfix<-lmer(key~is_stress_correct+newlogfreq+is_stress_correct:newlogfreq +(is_stress_correct:newlogfreq|subject)+(is_stress_correct|word)+(is_stress_correct:newlogfreq|stem1), data=expfix) #didn't converge

#mfix<-lmer(key~is_stress_correct+newlogfreq+is_stress_correct:newlogfreq +(is_stress_correct:newlogfreq|subject)+(is_stress_correct|word)+(is_stress_correct+newlogfreq|stem1), data=expfix) #this converged, and the qualitative patterns are the same as in the model we report. But comparing this model with less complex ones (minus each of the fixed factors) was not working well, and looking at the random effect structure revealed that log frequency had the smallest amount of variance in the stem1 random slope. So we are reporting a model with just a stem1 slope for is_stress_correct.

#sort(sapply(ranef(mfix)$subject, sd))
#sort(sapply(ranef(mfix)$stem1, sd))
#sort(sapply(ranef(mfix)$word, sd))


mfix1<-lmer(key~is_stress_correct+newlogfreq+is_stress_correct:newlogfreq +(is_stress_correct:newlogfreq|subject)+(is_stress_correct|word)+(is_stress_correct|stem1), data=expfix)
mfix2<-update(mfix1, .~. - is_stress_correct:newlogfreq); anova(mfix1,mfix2) #nsig, drop interaction
mfix3<-update(mfix2, .~. - newlogfreq); anova(mfix2,mfix3) #nsig, drop frequency

mfix1
mfix2
mfix3

#mfix3 is it

x<-mfix
x<-mfix3
x
round(2*(1-pt(abs(coef(summary(x))[,3]), Inf)), 4)

kappa.mer(x); max(vif.mer(x)); maxcorr.mer(x)

dev.new(height=3, width=10)
par(mfrow=c(1,3))

plot(fitted(x), resid(x))
rug(fitted(x)); rug(resid(x), side=4)
qqnorm(resid(x)); qqline(resid(x), col='red', lty=3)

m.mu = mean(resid(x)); m.sd = sd(resid(x))
hist(resid(x), breaks=40, freq=FALSE, xlim=c(-3, 3))
curve(dnorm(x, m.mu, m.sd), col='red', add=TRUE)

#testing to see whether inclusion of ranefs is justified

mfix3.1<-update(mfix3, .~. - (is_stress_correct:newlogfreq|subject)); 
anova(mfix3,mfix3.1) #sig
mfix3.2<-update(mfix3, .~. - (is_stress_correct|word)); 
anova(mfix3,mfix3.2) #sig
mfix3.3<-update(mfix3, .~. - (is_stress_correct|stem1)); 
anova(mfix3,mfix3.3) #sig


###########################################
###########################################
###########################################



#MOBILEMOBILEMOBILEMOBILEMOBILE
#MOBILEMOBILEMOBILEMOBILEMOBILE
#MOBILEMOBILEMOBILEMOBILEMOBILE

colnames(expmob)
expmob$stress_loc=expmob$linker_stress
expmob$stress_loc=factor(expmob$stress_loc)
expmob$stress_loc=gsub("TRUE", "linker", expmob$stress_loc)
expmob$stress_loc=gsub("FALSE", "elsewhere", expmob$stress_loc)
expmob$stress_loc=ifelse(expmob$is_there_sec_stress==FALSE, "no_stress", expmob$stress_loc)
expmob$stress_loc=factor(expmob$stress_loc)
expmob$stress_loc<-relevel(expmob$stress_loc, "no_stress")
#summary(expmob)


#descriptive stats
aggregate(key~is_there_sec_stress, expmob, mean)
summary(expmob)

############################################
#Lmers

#model for mobile stems was too collinear w/o centering (k= 32, vif=7.31, maxcorr=-0.92)
#mmob1<-lmer(key~is_there_sec_stress+newlogfreq+is_there_sec_stress*newlogfreq+(is_there_sec_stress*newlogfreq|subject)+(1+is_there_sec_stress|word), data=expmob) #too collinear: k = 32.1, vif = 9.78, maxcorr= -0.95

#did not converge: full model with stem1 slope for stress presence

#mmob1<-lmer(key~is_there_sec_stress+c.(newlogfreq)+is_there_sec_stress:c.(newlogfreq)+(is_there_sec_stress*c.(newlogfreq)|subject)+(1+is_there_sec_stress|word) + (1+is_there_sec_stress|stem1), data=expmob)

mmob2<-lmer(key~is_there_sec_stress+newlogfreq+is_there_sec_stress:newlogfreq+(is_there_sec_stress*newlogfreq|subject)+(1+is_there_sec_stress|word) + (1|stem1), data=expmob)

mmob3<-lmer(key~is_there_sec_stress+c.(newlogfreq)+is_there_sec_stress:c.(newlogfreq)+(is_there_sec_stress*c.(newlogfreq)|subject)+(1+is_there_sec_stress|word) + (1|stem1), data=expmob)

x<-mmob2;x
x<-mmob3; x
round(2*(1-pt(abs(coef(summary(x))[,3]), Inf)), 4)
kappa.mer(x); max(vif.mer(x)); maxcorr.mer(x)

#Plotting the residuals
dev.new(height=4, width=12)
par(mfrow=c(1,3))

plot(fitted(x), resid(x))
rug(fitted(x)); rug(resid(x), side=4)
qqnorm(resid(x)); qqline(resid(x), col='red', lty=3)

m.mu = mean(resid(x)); m.sd = sd(resid(x))
hist(resid(x), breaks=40, freq=FALSE, xlim=c(-3, 3))
curve(dnorm(x, m.mu, m.sd), col='red', add=TRUE)

#Model comparisons to see if ranefs are justified

mmob3.1<-update(mmob3, .~. - (is_there_sec_stress*c.(newlogfreq)|subject)); anova(mmob3,mmob3.1)
mmob3.2<-update(mmob3, .~. - (1+is_there_sec_stress|word)); anova(mmob3,mmob3.2)
mmob3.3<-update(mmob3, .~. - (1|stem1)); anova(mmob3,mmob3.3) #no, nonsig (df=1, chisq = 0.09, p=0.767)


####################################
####################################
####################################

#FINALFINALFINALFINALFINAL
#FINALFINALFINALFINALFINAL
#FINALFINALFINALFINALFINAL

#descriptive stats
colnames(expfin)
levels(expfin$vlesson)

expvless<-subset(exp, vowelless_root==TRUE)

aggregate(key~interstress_distance, expvless, mean)
aggregate(key~sonority_fall, expfin, mean)
aggregate(key~sonority_fall, expvless, mean)
aggregate(key~is_there_sec_stress, expfin, mean)
aggregate(key~is_there_sec_stress, expfin, mean)



summary(subset(expfin, sonority_fall==TRUE & is_there_sec_stress==TRUE))
summary(subset(expfin, sonority_fall==TRUE & is_there_sec_stress==FALSE))
summary(subset(expfin, sonority_fall==FALSE & is_there_sec_stress==TRUE))
summary(subset(expfin, sonority_fall==FALSE & is_there_sec_stress==FALSE))


mean(expfin[expfin$vlesson=="long"&expfin$is_there_sec_stress==TRUE, ]$key)
mean(expfin[expfin$vlesson=="long"&expfin$is_there_sec_stress==FALSE, ]$key)
mean(expfin[expfin$vlesson=="CC-"&expfin$is_there_sec_stress==TRUE, ]$key)
mean(expfin[expfin$vlesson=="CC-"&expfin$is_there_sec_stress==FALSE, ]$key)
mean(expfin[expfin$vlesson=="RC-"&expfin$is_there_sec_stress==TRUE, ]$key)
mean(expfin[expfin$vlesson=="RC-"&expfin$is_there_sec_stress==FALSE, ]$key)


expvful<-subset(expfin, vowelless_root==FALSE)

summary(expfin)

#did not converge:

#mfin1<-lmer(key~c.(newlogfreq)+
#is_there_sec_stress
#+is_there_sec_stress:vlesson
#+(is_there_sec_stress+vlesson|subject) 
#+(is_there_sec_stress|stem1)
#+(is_there_sec_stress|word),
#data=expfin)

#sort(sapply(ranef(mfin1)$subject, sd))
#sort(sapply(ranef(mfin1)$stem1, sd))
#sort(sapply(ranef(mfin1)$word, sd)) #word variance is smallest, trying just intercept

mfin<-lmer(key~c.(newlogfreq)+
is_there_sec_stress
+vlesson
+is_there_sec_stress:vlesson
+(1+is_there_sec_stress+vlesson|subject) 
+(1+is_there_sec_stress+c.(newlogfreq)|stem1)
+(1|word),
data=expfin)

x<-mfin
x
round(2*(1-pt(abs(coef(summary(x))[,3]), Inf)), 4)
kappa.mer(x); max(vif.mer(x)); maxcorr.mer(x) 

dev.new(height=4, width=12)
par(mfrow=c(1,3))

plot(fitted(x), resid(x))
rug(fitted(x)); rug(resid(x), side=4)
qqnorm(resid(x)); qqline(resid(x), col='red', lty=3)

m.mu = mean(resid(x)); m.sd = sd(resid(x))
hist(resid(x), breaks=40, freq=FALSE, xlim=c(-3, 3))
curve(dnorm(x, m.mu, m.sd), col='red', add=TRUE)

sort(sapply(ranef(mfin)$word, sd))
sort(sapply(ranef(mfin)$subject, sd))
sort(sapply(ranef(mfin)$stem1, sd))

mfin1.1<-update(mfin, .~. - (1+is_there_sec_stress+vlesson|subject) ); anova (mfin,mfin1.1)
mfin1.2<-update(mfin, .~. - (1+is_there_sec_stress+c.(newlogfreq)|stem1) ); anova (mfin,mfin1.2)
#mfin1.3<-update(mfin, .~. - (1|word)); anova(mfin,mfin1.3) #did not converge w/o this ranef



############################################################
############################################################
############################################################


# Packages and function for making charts
library(lattice)
library(languageR)
library(beanplot)

setwd(chartdir)
chartmode = "screen"
chartmode = "pdf"
myfont = "Linux Libertine"; pointsize=14
quartz.fnc = function(cwidth,cheight,cname) {
	if(chartmode=="screen") {
		quartz(width=cwidth,height=cheight)
	}
	if(chartmode=="pdf") {
		quartz(width=cwidth,height=cheight,type="pdf",file=cname)
	}
}

#The definition of stress clash

#Figure 3: ratings by interstress distance, all words except fixed w moved stress
quartz.fnc(cwidth=6,cheight=5,cname="beanplot_defn_of_clash.pdf")
	par(family=myfont,ps=pointsize,mar=c(5,4,1,1))
	beanplot(key~interstress_distance, data=subset(exp, interstress_distance<5 & is_stress_correct!="moved"), log="", 
	what=c(0,1,1,0), bw=.4, yaxt="n", boxwex = 1, cex.axis=1,
	xlab="Number of syllables between stresses",  
	ylab="best                             worst");
	axis(2,seq(1,7,1),seq(1,7,1))
if (chartmode=="pdf") {dev.off()}


#Figure 4: Effects of clash, all stress types side by side


quartz.fnc(cwidth=10,cheight=10,cname="beanplot_clash_effects.pdf")
		par(mfrow=c(2,2), family=myfont,ps=pointsize,mar=c(5,5,1,1))		
		beanplot(key~interstress_distance, data=subset(expsec, stress_type2=="fixed" & is_stress_moved==FALSE), log="",
		what=c(0,1,1,0), bw=.3, yaxt="n", boxwex = .9, cex.axis=1, 
		xlab="Fixed stress", 
		ylab="best                                             worst") 
		axis(2,seq(1,7,1), seq(1,7,1))

		beanplot(key~interstress_distance, data=subset(expsec, stress_type2=="final"), log="", what=c(0,1,1,0), bw=.3, yaxt="n", boxwex = .9, cex.axis=1, 
		xlab="Final stress",
		ylab="best                                             worst") 
		axis(2,seq(1,7,1), seq(1,7,1))
		
		beanplot(key~interstress_distance, data=subset(expsec, stress_type2=="mobile"), log="", 
		what=c(0,1,1,0), bw=.3, yaxt="n", boxwex = 		.9, cex.axis=1, 
		xlab="Mobile stress", 
		ylab="best                                             worst")
		axis(2,seq(1,7,1), seq(1,7,1))
	
		beanplot(key~interstress_distance, data=subset(expsec, stress_type2=="vless"), log="", 
		what=c(0,1,1,0), bw=.3, yaxt="n", boxwex = 		.9, cex.axis=1, 
		xlab="Vowelless final", 
		ylab="best                                             worst")
		axis(2,seq(1,7,1), seq(1,7,1))
			
		
if (chartmode=="pdf") {dev.off()}

#Figure 5: An initial default for secondary stress?

quartz.fnc(cwidth=7,cheight=5,cname="beanplot_initial_default.pdf")
	par(family=myfont,ps=pointsize,mar=c(6,4,2,2))

	beanplot(key~interstress_distance, data=subset(exp, sec_loc==1 & is_stress_correct!="moved"), log="", 
	what=c(0,1,1,0), bw=.4, yaxt="n", boxwex = 1, cex.axis=1,
	xlab="Ratings by stress distance, initial stress wds",  
	ylab="best                             worst");
	axis(2,seq(1,7,1),seq(1,7,1))
if (chartmode=="pdf") {dev.off()}


#Frequency effects, scatterplots and reg lines

#Figure 8: Mobile 

quartz.fnc(cwidth=10,cheight=4,cname="freq_sec_stress_side_mob.pdf")
	par(family=myfont,ps=pointsize,mar=c(4,4,1,1), mfrow=c(1,2))

	plot(jitter(key)~jitter(c.(newlogfreq), factor=2.5), data=subset(expmob, is_there_sec_stress==TRUE), 
		ylab="best                       worst",  
		xlab="Log frequency, secondary stress",
		xlim=c(0,5))
		abline(lm(key~c.(newlogfreq), data=subset(expmob, is_there_sec_stress==TRUE)))
	plot(jitter(key)~jitter(c.(newlogfreq), factor=2.5), data=subset(expmob, is_there_sec_stress==FALSE), 
		ylab="best                       worst", 
		xlab="Log frequency, no secondary stress",
		xlim=c(0,5))		
		abline(lm(key~c.(newlogfreq), data=subset(expmob, is_there_sec_stress==FALSE)))
if (chartmode=="pdf") {dev.off()}


#Figure 7: Fixed, as a function of stress manipulation
quartz.fnc(cwidth=10,cheight=3,cname="freq_sec_stress_side_fix_manip.pdf")
	par(family=myfont,ps=pointsize,mar=c(4,4,1,1), mfrow=c(1,3))
	plot(jitter(key)~jitter(newlogfreq), data=subset(expfix, is_stress_correct=="correct"),  
		ylab="best                                 worst",  
		xlab="Log frequency, correct stress")
		abline(lm(key~newlogfreq, data=subset(expfix, is_stress_correct=="correct")))

	plot(jitter(key)~jitter(newlogfreq), data=subset(expfix, is_stress_correct=="deleted"), 
		#ylab="best                                 worst", 
		ylab='',
		xlab="Log frequency, deleted stress")
		abline(lm(key~newlogfreq, data=subset(expfix, is_stress_correct=="deleted")))
	plot(jitter(key)~jitter(newlogfreq), data=subset(expfix, is_stress_correct=="moved"),  
		#ylab="best                                 worst",  
		ylab='',
		xlab="Log frequency, moved stress")
		abline(lm(key~newlogfreq, data=subset(expfix, is_stress_correct=="moved")))

if (chartmode=="pdf") {dev.off()}


#Figure 10: Final

quartz.fnc(cwidth=10,cheight=4,cname="freq_sec_stress_side_fin.pdf")
	par(family=myfont,ps=pointsize,mar=c(4,4,1,1), mfrow=c(1,2))
	plot(jitter(key)~jitter(newlogfreq), data=subset(expfin, is_there_sec_stress==TRUE), 
		ylab="best                       worst",  
		xlab="Log frequency, secondary stress")
		abline(lm(key~newlogfreq, data=subset(expfin, is_there_sec_stress==TRUE)))

	plot(jitter(key)~jitter(newlogfreq), data=subset(expfin, is_there_sec_stress==FALSE), 
		ylab="best                       worst", 
		xlab="Log frequency, no secondary stress")
		abline(lm(key~newlogfreq, data=subset(expfin, is_there_sec_stress==FALSE)))
if (chartmode=="pdf") {dev.off()}


###################################

#Figure 9: Mobile stems: effect of stress clash and sec stress location

quartz.fnc(cwidth=6,cheight=4,cname="beanplot_mobile_interstress_dist.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,1,1)); 
	beanplot(key~interstress_distance, data=expmob, log="", 
		what=c(0,1,1,0), bw=.35, yaxt="n", xaxt="n", boxwex = .9, cex.axis=1,
		ylab="best                    worst", xlab="Syllables between stresses"); 
	axis(2,seq(1,7,1),seq(1,7,1))
	axis(1, 1:5, c("0", "1", "2", "3", "no stress"), cex=2)
if (chartmode=="pdf") {dev.off()}

quartz.fnc(cwidth=5,cheight=4,cname="beanplot_mobile_sec_stress_presence.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,1,1)); 
	beanplot(key~is_there_sec_stress, data=expmob, log="", 
		what=c(0,1,1,0), bw=.35, yaxt="n", xaxt="n", boxwex = .9, cex.axis=1,
		ylab="best                    worst", xlab="Presence of secondary stress"); 
	axis(2,seq(1,7,1),seq(1,7,1))
	axis(1, 1:2, c("no stress", "stress"), cex=2)
if (chartmode=="pdf") {dev.off()}



#Figure 6: fixed stress: Effects of stress manipulation

quartz.fnc(cwidth=6,cheight=4,cname="beanplot_fixed_stress_correct.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,1,1)); 
	beanplot(key~is_stress_correct[drop=T], data=expfix, log="", 
		what=c(0,1,1,0), bw=.35, yaxt="n", boxwex = .9, cex.axis=1,
		ylab="best                  worst", xlab="Stress manipulation"); 
	axis(2,seq(1,7,1),seq(1,7,1))
if (chartmode=="pdf") {dev.off()}

#figure 11: Final stress stems: show effects of stress clash, secondary stress, and vowellessness

quartz.fnc(cwidth=7,cheight=5,cname="beanplot_vowellessness_sonority.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,1,10)); 
	beanplot(key~is_there_sec_stress+vlesson, 
		data=expfin,
		side="both",
		log="",
		what=c(0,1,1,0), bw=.3, yaxt="n", boxwex =1, cex.axis=1, col=list("black", "gray50"), ylab="best                       worst");
		axis(2,seq(1,7,1));
		legend(x=4, y=3.4, c("stress", "no stress"), fill=c("gray50", "black"), xpd=T, inset=-.01, bg="white")	
if (chartmode=="pdf") {dev.off()}




###############################################################
###############################################################
###########	THE END THE END THE END THE END ###################
###############################################################
###############################################################

#Plots that didn't make it into the paper


chartmode="screen"

boxplot(key~sec_loc, data=subset(exp, stem1=="golov"))
boxplot(key~sec_loc, data=subset(exp, stem1=="korabl"))
boxplot(key~sec_loc, data=subset(exp, stem1=="zakon"))
boxplot(key~sec_loc, data=subset(exp, stem1=="kukuruz"))
boxplot(key~sec_loc, data=subset(exp, stem1=="jestestv"))



#What did the subjects do?
xylowess.fnc(key~trial|subject, data=exp)



quartz.fnc(cwidth=6,cheight=4,cname="beanplot_golov.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3)); 
	beanplot(key~sec_loc, data=subset(exp, stem1=="golov"), log="", 
		what=c(0,1,1,0), bw=.35, yaxt="n", boxwex = .9, cex.axis=1,
		ylab="best                  worst", xlab="golov-: stress location"); 
	axis(2,seq(1,7,1),seq(1,7,1))
if (chartmode=="pdf") {dev.off()}

quartz.fnc(cwidth=6,cheight=4,cname="beanplot_korabl.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3)); 
	beanplot(key~sec_loc, data=subset(exp, stem1=="korabl"), log="", 
		what=c(0,1,1,0), bw=.35, yaxt="n", boxwex = .9, cex.axis=1,
		ylab="best                  worst", xlab="korabl-: stress location"); 
	axis(2,seq(1,7,1),seq(1,7,1))
if (chartmode=="pdf") {dev.off()}

quartz.fnc(cwidth=6,cheight=4,cname="beanplot_zakon.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3)); 
	beanplot(key~sec_loc, data=subset(exp, stem1=="zakon"), log="", 
		what=c(0,1,1,0), bw=.35, yaxt="n", boxwex = .9, cex.axis=1,
		ylab="best                  worst", xlab="zakon-: stress location"); 
	axis(2,seq(1,7,1),seq(1,7,1))
if (chartmode=="pdf") {dev.off()}

quartz.fnc(cwidth=6,cheight=4,cname="beanplot_kukuruz.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3)); 
	beanplot(key~sec_loc, data=subset(exp, stem1=="kukuruz"), log="", 
		what=c(0,1,1,0), bw=.35, yaxt="n", boxwex = .9, cex.axis=1,
		ylab="best                  worst", xlab="kukuruz-: stress location"); 
	axis(2,seq(1,7,1),seq(1,7,1))
if (chartmode=="pdf") {dev.off()}

quartz.fnc(cwidth=6,cheight=4,cname="beanplot_jestestv.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3)); 
	beanplot(key~sec_loc, data=subset(exp, stem1=="jestestv"), log="", 
		what=c(0,1,1,0), bw=.35, yaxt="n", boxwex = .9, cex.axis=1,
		ylab="best                  worst", xlab="jestestv-: stress location"); 
	axis(2,seq(1,7,1),seq(1,7,1))
if (chartmode=="pdf") {dev.off()}


#ratings as a function of wordlength
quartz.fnc(cwidth=6,cheight=5,cname="beanplot_adjacent_stress_by_wd_length.pdf")
	par(family=myfont,ps=pointsize,mar=c(5,4,2,2))
	beanplot(key~syllcount, data=subset(exp, interstress_distance==0 & is_stress_correct!="moved" & stress_type2!="vless"), log="", 
	what=c(0,1,1,0), bw=.4, yaxt="n", boxwex = 1, cex.axis=1,
	xlab="Number of syllables in the word",  
	ylab="best                             worst");
	axis(2,seq(1,7,1),seq(1,7,1))
	
if (chartmode=="pdf") {dev.off()}


#ratings for stress on linker

quartz.fnc(cwidth=5,cheight=4,cname="beanplot_linker_stress.pdf")
	par(family=myfont,ps=pointsize,mar=c(5,4,2,2))
	beanplot(key~linker_stress, data=subset(exp, interstress_distance<5 & vowelless_root==FALSE), log="", 
	what=c(0,1,1,0), bw=.35, yaxt="n", xaxt="n", boxwex = 1, cex.axis=1,
	xlab="Is stress on the linker vowel?",  
	ylab="best                             worst");
	axis(2,seq(1,7,1),seq(1,7,1));
	axis(1, 1:2, c("not linker", "linker"))
if (chartmode=="pdf") {dev.off()}

#ratings for just the moved stresses
quartz.fnc(cwidth=6,cheight=5,cname="beanplot_interestress_moved.pdf")
	par(family=myfont,ps=pointsize,mar=c(5,4,2,2))
	beanplot(key~interstress_distance, data=subset(exp, interstress_distance<5 & is_stress_correct=="moved"), log="", 
	what=c(0,1,1,0), bw=.4, yaxt="n", boxwex = 1, cex.axis=1,
	xlab="Moved stress: ratings by syllables between stresses",  
	ylab="best                             worst");
	axis(2,seq(1,7,1),seq(1,7,1))
	
if (chartmode=="pdf") {dev.off()}

#Are interstress distance effects more visible if we exclude RC stems? sorta

quartz.fnc(cwidth=10,cheight=10,cname="beanplot_clash_effects_no_RC.pdf")
		par(mfrow=c(2,2), family=myfont,ps=pointsize,mar=c(5,5,2,2))		
		beanplot(key~interstress_distance, data=subset(expsec, stress_type2=="fixed" & is_stress_moved==FALSE), log="",
		what=c(0,1,1,0), bw=.3, yaxt="n", boxwex = .9, cex.axis=1, 
		xlab="Fixed stress", 
		ylab="best                                             worst") 
		axis(2,seq(1,7,1), seq(1,7,1))

		beanplot(key~interstress_distance, data=subset(expsec, stress_type2=="final"), log="", what=c(0,1,1,0), bw=.3, yaxt="n", boxwex = .9, cex.axis=1, 
		xlab="Final stress",
		ylab="best                                             worst") 
		axis(2,seq(1,7,1), seq(1,7,1))
		
		beanplot(key~interstress_distance, data=subset(expsec, stress_type2=="mobile"), log="", 
		what=c(0,1,1,0), bw=.3, yaxt="n", boxwex = 		.9, cex.axis=1, 
		xlab="Mobile stress", 
		ylab="best                                             worst")
		axis(2,seq(1,7,1), seq(1,7,1))
	
		beanplot(key~interstress_distance, data=subset(expsec, stress_type2=="vless" & sonority_fall==FALSE), log="", 
		what=c(0,1,1,0), bw=.3, yaxt="n", boxwex = 		.9, cex.axis=1, 
		xlab="Vowelless final", 
		ylab="best                                             worst")
		axis(2,seq(1,7,1), seq(1,7,1))
			
		
if (chartmode=="pdf") {dev.off()}

#Interstress distance, with all the data (including no stress)
quartz.fnc(cwidth=10,cheight=10,cname="beanplot_clash_effects_all.pdf")
		par(mfrow=c(2,2), family=myfont,ps=pointsize,mar=c(5,5,2,2))		
		beanplot(key~interstress_distance, data=subset(exp, stress_type2=="fixed"), log="",
		what=c(0,1,1,0), bw=.3, yaxt="n", boxwex = .9, cex.axis=1, 
		xlab="Fixed stress", 
		ylab="best                                             worst") 
		axis(2,seq(1,7,1), seq(1,7,1))

		beanplot(key~interstress_distance, data=subset(exp, stress_type2=="final"), log="", what=c(0,1,1,0), bw=.3, yaxt="n", boxwex = .9, cex.axis=1, 
		xlab="Final stress",
		ylab="best                                             worst") 
		axis(2,seq(1,7,1), seq(1,7,1))
		
		beanplot(key~interstress_distance, data=subset(exp, stress_type2=="mobile"), log="", 
		what=c(0,1,1,0), bw=.3, yaxt="n", boxwex = 		.9, cex.axis=1, 
		xlab="Mobile stress", 
		ylab="best                                             worst")
		axis(2,seq(1,7,1), seq(1,7,1))
	
		beanplot(key~interstress_distance, data=subset(exp, stress_type2=="vless"), log="", 
		what=c(0,1,1,0), bw=.3, yaxt="n", boxwex = 		.9, cex.axis=1, 
		xlab="Vowelless final", 
		ylab="best                                             worst")
		axis(2,seq(1,7,1), seq(1,7,1))
			
		
if (chartmode=="pdf") {dev.off()}


#Frequency effects on mobile stems

quartz.fnc(cwidth=10,cheight=4,cname="freq_sec_stress_side_mob.pdf")
	par(family=myfont,ps=pointsize,mar=c(4,4,3,4), mfrow=c(1,2))

	plot(jitter(key)~jitter(newlogfreq), data=subset(expmob, is_there_sec_stress==TRUE), 
		ylab="best                       worst",  
		xlab="Log frequency, secondary stress")
		abline(lm(key~newlogfreq, data=subset(expmob, is_there_sec_stress==TRUE)))
	plot(jitter(key)~jitter(newlogfreq), data=subset(expmob, is_there_sec_stress==FALSE), 
		ylab="best                       worst", 
		xlab="Log frequency, no secondary stress")
		abline(lm(key~newlogfreq, data=subset(expmob, is_there_sec_stress==FALSE)))
if (chartmode=="pdf") {dev.off()}


#Presence of secondary stress

quartz.fnc(cwidth=10,cheight=4,cname="beanplot_secstress_effects.pdf")
		par(mfrow=c(1,3), family=myfont,ps=pointsize,mar=c(5,5,2,2))	
		beanplot(key~is_there_sec_stress, 
		data=subset(expfix, is_stress_correct!="moved"& interstress_distance>0), 
		log="",
		what=c(0,1,1,0), bw=.3, yaxt="n", boxwex = .9, cex.axis=1, 
		xlab="Fixed", ylab="best                                              worst", 
		names=c("no stress", "stress")
		); 
		axis(2,seq(1,7,1), seq(1,7,1))

		beanplot(key~is_there_sec_stress, 
		data=subset(expfin, lexcons==TRUE & interstress_distance>0), 
		log="", 
		what=c(0,1,1,0), bw=.3, yaxt="n", boxwex = .9, cex.axis=1, 
		xlab="Final",
		names=c("no stress", "stress")
		); 
		axis(2,seq(1,7,1), seq(1,7,1))
		
		beanplot(key~is_there_sec_stress, 
		data=subset(expmob, interstress_distance>0), 
		log="", 
		what=c(0,1,1,0), bw=.3, yaxt="n", boxwex = 		.9, cex.axis=1, 
		xlab="Mobile", 
		names=c("no stress", "stress")
		); 
		axis(2,seq(1,7,1), seq(1,7,1))

if (chartmode=="pdf") {dev.off()}


#Frequency, all
quartz.fnc(cwidth=10,cheight=4,cname="freq_sec_stress_all.pdf")
	par(family=myfont,ps=pointsize,mar=c(4,4,3,4), mfrow=c(1,2))

	plot(jitter(key)~jitter(newlogfreq), data=subset(exp, is_there_sec_stress==TRUE), 
		ylab="best                       worst",  
		xlab="Log frequency, secondary stress")
		abline(lm(key~newlogfreq, data=subset(exp, is_there_sec_stress==TRUE)))

	plot(jitter(key)~jitter(newlogfreq), data=subset(exp, is_there_sec_stress==FALSE), 
		ylab="best                       worst", 
		xlab="Log frequency, no secondary stress")
			abline(lm(key~newlogfreq, data=subset(exp, is_there_sec_stress==FALSE)))
if (chartmode=="pdf") {dev.off()}

#Fixed: yes stress vs no stress
quartz.fnc(cwidth=10,cheight=4,cname="freq_sec_stress_side_fix.pdf")
	par(family=myfont,ps=pointsize,mar=c(4,4,3,4), mfrow=c(1,2))
	plot(jitter(key)~jitter(newlogfreq), data=subset(expfix, is_there_sec_stress==TRUE),  
		ylab="best                       worst",  
		xlab="Log frequency, secondary stress")
		abline(lm(key~newlogfreq, data=subset(expfix, is_there_sec_stress==TRUE)))

	plot(jitter(key)~jitter(newlogfreq), data=subset(expfix, is_there_sec_stress==FALSE), 
		ylab="best                       worst", 
		xlab="Log frequency, no secondary stress")
		abline(lm(key~newlogfreq, data=subset(expfix, is_there_sec_stress==FALSE)))
if (chartmode=="pdf") {dev.off()}
chartmode='pdf'

#Frequency, final vowelful
quartz.fnc(cwidth=10,cheight=4,cname="freq_sec_stress_side_vful.pdf")
	par(family=myfont,ps=pointsize,mar=c(4,4,3,4), mfrow=c(1,2))
	plot(jitter(key)~jitter(newlogfreq), data=subset(expvful, is_there_sec_stress==TRUE), 
		ylab="best                       worst",  
		xlab="Log frequency, secondary stress")
		abline(lm(key~newlogfreq, data=subset(expvful, is_there_sec_stress==TRUE)))

	plot(jitter(key)~jitter(newlogfreq), data=subset(expvful, is_there_sec_stress==FALSE), 
		ylab="best                       worst", 
		xlab="Log frequency, no secondary stress")
		abline(lm(key~newlogfreq, data=subset(expvful, is_there_sec_stress==FALSE)))
if (chartmode=="pdf") {dev.off()}

#Frequency, vowelless
quartz.fnc(cwidth=10,cheight=4,cname="freq_sec_stress_side_vless.pdf")
	par(family=myfont,ps=pointsize,mar=c(4,4,2,2), mfrow=c(1,2))
	plot(jitter(key)~jitter(newlogfreq), data=subset(expvless, is_there_sec_stress==TRUE), 
		ylab="best                       worst",  
		xlab="Log frequency, secondary stress")
		abline(lm(key~newlogfreq, data=subset(expfin, is_there_sec_stress==TRUE)))

	plot(jitter(key)~jitter(newlogfreq), data=subset(expvless, is_there_sec_stress==FALSE), 
		ylab="best                       worst", 
		xlab="Log frequency, no secondary stress")
		abline(lm(key~newlogfreq, data=subset(expvless, is_there_sec_stress==FALSE)))
if (chartmode=="pdf") {dev.off()}

#MOBILE stems effects of sec stress presence, no linker stress

quartz.fnc(cwidth=6,cheight=4,cname="beanplot_mobile_interstress_dist_nolink.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3)); 
	beanplot(key~interstress_distance, data=subset(expmob, linker_stress==FALSE), log="", 
		what=c(0,1,1,0), bw=.35, yaxt="n", xaxt="n", boxwex = .9, cex.axis=1,
		ylab="best                    worst", xlab="Syllables between stresses (excl. linker stress)"); 
	axis(2,seq(1,7,1),seq(1,7,1))
	axis(1, 1:4, c("1", "2", "3", "no stress"), cex=2)
if (chartmode=="pdf") {dev.off()}

#mobile, stress vs no stress

#mobile by syllable
quartz.fnc(cwidth=6,cheight=4,cname="beanplot_mobile_sec_loc.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,2,12)); 
	beanplot(key~sec_loc+interstress_distance, data=subset(expmob, linker_stress==FALSE & sec_stress!=0), 
	side="both", 
		what=c(0,1,1,0), bw=.35, yaxt="n", xaxt="n", boxwex = .9, cex.axis=1, col=list("black", "grey50"),
		ylab="best                    worst", xlab="Distance between stresses"); 
	axis(2,seq(1,7,1),seq(1,7,1))
	axis(1, 1:3, c("1 syll", "2 syll", "3 syll"), cex=2)
	legend(x=4, y=3.4, c("initial stress", "peninitial stress"), fill=c("black", "gray50"), xpd=T, inset=-.01, bg="white")
if (chartmode=="pdf") {dev.off()}


#Fixed stress: effects of clash

quartz.fnc(cwidth=6,cheight=4,cname="beanplot_fixed_interstress_dist.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3)); 
	beanplot(key~interstress_distance, 
	data=expfix, log="", 
	what=c(0,1,1,0), bw=.35, yaxt="n", xaxt="n", boxwex = .9, cex.axis=1, ylab="best                    worst", xlab="Syllables between stresses"); 
	axis(2,seq(1,7,1),seq(1,7,1));
	axis(1,1:6,c("0", "1", "2", "3", "4", "no stress"))
if (chartmode=="pdf") {dev.off()}

#Fixed stress: clash without moved stress stems 
quartz.fnc(cwidth=6,cheight=4,cname="beanplot_fixed_interstress_dist_excl_moved.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3)); 
	beanplot(key~interstress_distance, 
	data=subset(expfix, is_stress_correct!="moved"), log="", 
	what=c(0,1,1,0), bw=.35, yaxt="n", 
	xaxt="n", 
	boxwex = .9, cex.axis=1, ylab="best                    worst", xlab="Syllables between stresses"); 
	axis(2,seq(1,7,1),seq(1,7,1));
	axis(1,1:5,c("1", "2", "3", "4", "no stress"))
if (chartmode=="pdf") {dev.off()}

#Lexical conservatism: does stress fall on a vowel that's never stressed?
quartz.fnc(cwidth=6,cheight=4,cname="beanplot_final_lexcons.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3)); 
	beanplot(key~lexcons, 
		data=expfin,
		log="",
		what=c(0,1,1,0), bw=.35, yaxt="n", xaxt="n", boxwex =.9, cex.axis=1, ylab="best                        worst")
		axis(2,seq(1,7,1), seq(1,7,1));
		axis(1,1:2, c("non-conservative", "lexically conservative"));
if (chartmode=="pdf") {dev.off()}

#final stress stems: vowellessness and clash
quartz.fnc(cwidth=7,cheight=4,cname="beanplot_vowellessness_clash.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,2,8)); 
	beanplot(key~vowelless_root+interstress_distance, 
		data=expfin,
		side="both",
		what=c(0,1,1,0), bw=.35, yaxt="n", xaxt="n", boxwex =.9, cex.axis=1, col=list("black", "gray50"), ylab="best                       worst");
		axis(2,seq(1,7,1), seq(1,7,1))
		axis(1,1:5, c("0", "1", "2", "3", "no stress"));		
		legend(x=6, y=3.4, c("vowelless", "long"), fill=c("gray50", "black"), xpd=T, inset=-.01, bg="white")
	
if (chartmode=="pdf") {dev.off()}

#Effects of stress clash, final stems only

quartz.fnc(cwidth=6,cheight=4,cname="beanplot_final_interstress_dist.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3)); 
	beanplot(key~interstress_distance, 
		data=expfin,
		log="",
		what=c(0,1,1,0), bw=.35, yaxt="n", xaxt="n", boxwex =.9, cex.axis=1, ylab="best                       worst", xlab="Syllables between stresses")
		axis(2,seq(1,7,1), seq(1,7,1));
		axis(1,1:5, c("0", "1", "2", "3", "no stress"));
if (chartmode=="pdf") {dev.off()}

quartz.fnc(cwidth=7,cheight=4,cname="beanplot_sonority_clash.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,2,8)); 
	beanplot(key~sonority_fall+interstress_distance, 
		data=expfin,
		log="",
		side="both",
		what=c(0,1,1,0), bw=.35, yaxt="n", xaxt="n", boxwex =.9, cex.axis=1, col=list("black", "gray50"), ylab="best                       worst");
		axis(2,seq(1,7,1), seq(1,7,1))
		axis(1,1:5, c("0", "1", "2", "3", "no stress"));		
		legend(x=5.8, y=3.4, c("RC-", "long & CC-"), fill=c("gray50", "black"), xpd=T, inset=-.01, bg="white")
if (chartmode=="pdf") {dev.off()}

quartz.fnc(cwidth=7,cheight=4,cname="beanplot_linkerstress_sonority.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,2,10)); 
	beanplot(key~linker_stress+vlesson, 
		data=expfin,
		log="",
		side="both",
		what=c(0,1,1,0), bw=.35, yaxt="n", boxwex =.9, cex.axis=1, col=list("black", "gray50"), ylab="best                       worst");
		axis(2,seq(1,7,1), seq(1,7,1));
		legend(x=3.6, y=6, c("stress on linker V", "no/elsewhere stress"), fill=c("gray50", "black"), xpd=T, inset=-.01, bg="white")
if (chartmode=="pdf") {dev.off()}


quartz.fnc(cwidth=7,cheight=4,cname="beanplot_sonority_vless_clash.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,2,8)); 
	beanplot(key~sonority_fall+interstress_distance, 
		data=subset(exp, stress_type2="vless"),
		log="",
		side="both",
		what=c(0,1,1,0), bw=.35, yaxt="n", xaxt="n", boxwex =.9, cex.axis=1, col=list("black", "gray50"), ylab="best                       worst");
		axis(2,seq(1,7,1), seq(1,7,1))
		axis(1,1:6, c("0", "1", "2", "3", "4", "no stress"));		
		legend(x=6.8, y=3.4, c("RC-", "CC-"), fill=c("gray50", "black"), xpd=T, inset=-.01, bg="white")
if (chartmode=="pdf") {dev.off()}

quartz.fnc(cwidth=6,cheight=4,cname="beanplot_mobile_sec_loc_all.pdf"); 
	par(family=myfont, ps=pointsize, mar=c(4,4,3,3)); 
	beanplot(key~sec_loc, data=expmob, log="", 
		what=c(0,1,1,0), bw=.35, yaxt="n", xaxt="n", boxwex = .9, cex.axis=1,
		ylab="best                    worst", xlab="Location of secondary stress"); 
	axis(2,seq(1,7,1),seq(1,7,1))
	axis(1, 1:4, c("no stress", "1", "2", "3"), cex=2)
if (chartmode=="pdf") {dev.off()}


#Individual stems, stress location:

exp$sec_stress_inv=sqrt(4-exp$sec_stress)^2
golov.xtabs<-xtabs(~key+sec_stress_inv, data=subset(exp, stem1=="golov"))
korabl.xtabs<-xtabs(~key+sec_stress_inv, data=subset(exp, stem1=="korabl"))
zakon.xtabs<-xtabs(~key+sec_stress_inv, data=subset(exp, stem1=="zakon"))
kukuruz.xtabs<-xtabs(~key+sec_stress_inv, data=subset(exp, stem1=="kukuruz"))
jestestv.xtabs<-xtabs(~key+sec_stress_inv, data=subset(exp, stem1=="jestestv"))
oboron.xtabs<-xtabs(~key+sec_stress_inv, data=subset(exp, stem1=="oboron"))


golov.xtabs
korabl.xtabs
zakon.xtabs
kukuruz.xtabs
jestestv.xtabs

#word-level analysis of ratings, barplots:


quartz.fnc(cwidth=7,cheight=4,cname="xtabs_graph_oboron.pdf");
	par(family=myfont, ps=pointsize, mar=c(4,5,1,7));
	barplot(oboron.xtabs,
	names.arg=c("o", "bo", "ro", "no", "none"),
	ylab="Total N of key presses",
	legend.text=c("1", "2", "3", "4", "5", "6", "7"),
	args.legend=list(x=7, y=40)
    )
if (chartmode=="pdf") {dev.off()}


quartz.fnc(cwidth=7,cheight=4,cname="xtabs_graph_golov.pdf");
	par(family=myfont, ps=pointsize, mar=c(4,5,1,7));
	barplot(golov.xtabs,
	names.arg=c("go", "lo", "vo", "none"),
	ylab="Total N of key presses",
	legend.text=c("1", "2", "3", "4", "5", "6", "7"),
	args.legend=list(x=6, y=40)
    )
if (chartmode=="pdf") {dev.off()}

quartz.fnc(cwidth=7,cheight=4,cname="xtabs_graph_korabl.pdf");
	par(family=myfont, ps=pointsize, mar=c(4,5,1,7));
	barplot(korabl.xtabs,
	names.arg=c("ko", "ra", "ble", "none"),
	ylab="Total N of key presses",
	legend.text=c("1", "2", "3", "4", "5", "6", "7"),
	args.legend=list(x=6, y=15)
    )
if (chartmode=="pdf") {dev.off()}

quartz.fnc(cwidth=7,cheight=4,cname="xtabs_graph_zakon.pdf");
	par(family=myfont, ps=pointsize, mar=c(4,5,1,7));
	barplot(zakon.xtabs,
	names.arg=c("za", "ko", "no", "none"),
	ylab="Total N of key presses",
	legend.text=c("1", "2", "3", "4", "5", "6", "7"),
	args.legend=list(x=6, y=15)
    )
if (chartmode=="pdf") {dev.off()}

quartz.fnc(cwidth=7,cheight=4,cname="xtabs_graph_kukuruz.pdf");
	par(family=myfont, ps=pointsize, mar=c(4,5,1,7));
	barplot(kukuruz.xtabs,
	names.arg=c("ku1", "ku2", "ru", "zo", "none"),
	ylab="Total N of key presses",
	legend.text=c("1", "2", "3", "4", "5", "6", "7"),
	args.legend=list(x=7.5, y=15)
    )
if (chartmode=="pdf") {dev.off()}

quartz.fnc(cwidth=7,cheight=4,cname="xtabs_graph_jestestv.pdf");
	par(family=myfont, ps=pointsize, mar=c(4,5,1,7));
	barplot(jestestv.xtabs,
	names.arg=c("jes", "tes", "tvo", "none"),
	ylab="Total N of key presses",
	legend.text=c("1", "2", "3", "4", "5", "6", "7"),
	args.legend=list(x=6, y=15)
    )
if (chartmode=="pdf") {dev.off()}

