#Loading and recoding data
#Setting work and chart directories for R

workdir = "~/Documents/Dropbox/work/a_research/russian/russian_compounds/grammaticality_judgments_study/stats/" #for maria


chartdir = paste(workdir, "filler_graphs/", sep="")
datadir = paste(workdir, "data_files_cleanedup/", sep="")
setwd(datadir)

#importing
exp <- read.csv("compound_ratings_w_fillers.txt", sep="\t")
summary(exp)
exp$is.filler=ifelse(factor(substr(exp$sound_file, 1, 1))=="f", TRUE, FALSE)
exp$word=gsub("^[fs]_","", exp$sound_file)
exp$word=factor(gsub("(_[0-9].aif @ ::SoundFiles:)", "", exp$word))
head(exp)
fillers<-subset(exp, is.filler==TRUE)

setwd(workdir)
#source("mer-utils.txt"); source("regression-utils.R") -- #this is for lmer collinearity; uncomment if you want them. 


library(gdata)
filler_predictors<- read.xls("filler_ling_predictors.xls")
summary(filler_predictors)
fillers<-merge(fillers, filler_predictors)
fillers$subject=factor(fillers$subject)
fillers<-subset(fillers, subject!="13") #13 has to be eliminated from analysis because she didn't follow instructions. Although it might be worth it to check whether she just inverted the scale completely--she told me she switched to the "correct" scale at the end of the experiment or halfway through, but I never checked this.

levels(fillers$subject); length(levels(fillers$subject)); length(unique(fillers$subject)) # Just checking

fillers$X<-NULL; fillers$X.1<-NULL; fillers$X.2<-NULL; fillers$X.3<-NULL; fillers$junk<-NULL
fillers$interstress_distance<-fillers$prim_location-fillers$sec_location

# Create one field that allows a 3-way comparison of 1) secondary stress 2) No secondary stress with primary correct and 3) No secondary stress with primary wrong

fillers$stress.type=ifelse(fillers$sec_stress==TRUE, "secondary", ifelse(fillers$prim_stress_correct==TRUE, "primary_correct", "primary_moved"))
fillers$stress.type<-factor(fillers$stress.type)

summary(fillers)
head(fillers)

sexyfillers<-subset(fillers, stress.type=="secondary")
moviefillers<-subset(fillers, stress.type!="secondary")

###################################################
###################################################
###################################################

library(lme4)
library(arm)
library(languageR)
library(multcomp)
library(beanplot)
source("mer-utils.txt")
source("regression-utils.R")

fsec1<-lmer(key~1+(1|subject), data=fillers)
fsec2<-lmer(key~sec_stress+(1|subject), data=fillers)
anova(fsec1,fsec2)
fsec2

fsec3<-lmer(key~sec_stress+(1|subject)+(1|word), data=fillers)
anova(fsec2,fsec3)

x<-fsec3
x
round(2*(1-pt(abs(coef(summary(x))[,3]), Inf)), 4)

kappa.mer(x); max(vif.mer(x)); maxcorr.mer(x)

dev.new(height=3, width=10)
par(mfrow=c(1,3))

plot(fitted(x), resid(x))
rug(fitted(x)); rug(resid(x), side=4)
qqnorm(resid(x)); qqline(resid(x), col='red', lty=3)

m.mu = mean(resid(x)); m.sd = sd(resid(x))
hist(resid(x), breaks=40, freq=FALSE, xlim=c(-1.5, 1.5))
curve(dnorm(x, m.mu, m.sd), col='red', add=TRUE)

##########################################
##########################################
##########################################

#Models for secondary stress
sec1<-lmer(key~1+(1|subject), data=sexyfillers)
sec2<-lmer(key~interstress_distance+(1|subject), data=sexyfillers)
anova(sec1,sec2)
sec2

sec3<-lmer(key~interstress_distance+(1|subject)+(1|word), data=sexyfillers)
anova(sec2,sec3)
sec3

x<-sec3
x
round(2*(1-pt(abs(coef(summary(x))[,3]), Inf)), 4)

kappa.mer(x); max(vif.mer(x)); maxcorr.mer(x)

dev.new(height=3, width=10)
par(mfrow=c(1,3))

plot(fitted(x), resid(x))
rug(fitted(x)); rug(resid(x), side=4)
qqnorm(resid(x)); qqline(resid(x), col='red', lty=3)

m.mu = mean(resid(x)); m.sd = sd(resid(x))
hist(resid(x), breaks=40, freq=FALSE, xlim=c(-1.5, 1.5))
curve(dnorm(x, m.mu, m.sd), col='red', add=TRUE)

####################################################
####################################################
####################################################

summary(sexyfillers)
unique(sexyfillers$word)
unique(sexyfillers$sound_file)

# The graph is sort of in line with the interstress distance trend, though the numbers aren't huge here (only 903 items rated), so 

chartmode = "pdf" # select one of these to either display the chart on the screen or print to PDF
chartmode = "screen"
myfont = "Linux Libertine"; pointsize=14 #You have to have Linux Libertine installed--but it's free and beautiful
quartz.fnc = function(cwidth,cheight,cname) {
	if(chartmode=="screen") {
		quartz(width=cwidth,height=cheight)
	}
	if(chartmode=="pdf") {
		quartz(width=cwidth,height=cheight,type="pdf",file=cname)
	}
}	#Function for printing. All it does is give shortcut names to parameters that are otherwise a pain in the ass to set manually


######################################################
######################################################
######################################################

summary(fillers)

setwd(chartdir)


#Fillers with secondary stress:
quartz.fnc(cwidth=6,cheight=5,cname="beanplot_interstress_distance_fillers.pdf")
	par(family=myfont,ps=pointsize,mar=c(5,4,2,2))
	beanplot(key~interstress_distance, data=subset(sexyfillers, prim_stress_correct==TRUE), log="", 
#	beanplot(key~sec_stress, data=subset(fillers, prim_stress_correct!="moved"), log="", 
	what=c(0,1,1,0), bw=.4, yaxt="n", boxwex = 1, cex.axis=1,
	xlab="Ratings of fillers as a function of # of syllables between the stresses",  
	ylab="best                             worst");
	axis(2,seq(1,7,1),seq(1,7,1))
if (chartmode=="pdf") {dev.off()}	

#summary(moviefillers)

#Fillers without secondary stress:
chartmode="pdf"
quartz.fnc(cwidth=6,cheight=5,cname="beanplot_correct_vs_moved_fillers.pdf")
	par(family=myfont,ps=pointsize,mar=c(5,4,2,2))
	beanplot(key~stress.type[drop=T], data=moviefillers, log="", 
	what=c(0,1,1,0), bw=.4, yaxt="n", xaxt="n", boxwex = 1, cex.axis=1,
	xlab="",  
	ylab="best                             worst");
	axis(1, 1:2, c("Primary correct", "Primary moved"))
	axis(2,seq(1,7,1),seq(1,7,1))

if (chartmode=="pdf") {dev.off()}	

#KDR added this in to get numbers for the simple comparison of correct vs. incorrect primary stress
moved1<-lmer(key~1+(1|subject), data=moviefillers)
moved2<-lmer(key~prim_stress_correct+(1|subject), data=moviefillers)
anova(moved1,moved2)
moved2

moved3<-lmer(key~prim_stress_correct+(1|subject)+(1|word), data=moviefillers)
anova(moved2,moved3)
moved3
mean.notmoved<-subset(moviefillers, prim_stress_correct==TRUE)
mean.moved<-subset(moviefillers, prim_stress_correct==FALSE)
mean(mean.notmoved$key)
mean(mean.moved$key)

#unique(sexyfillers[sexyfillers$interstress_distance==3,]$word)


#Key to the filler predictors: prim_location indicates syllable bearing stress, counting from the left edge (e.g., in administratsija_1, stress is in its lexical location on the 4th syllable, so prim_stress == 4). The predictor sec_stress indicates the position of secondary stress counting from the left edge, so administratsija_2 has a value of 1 for that variable. For words without secondary stress, sec_stress has the value NA (so administratsija_1 has NA). For prim_stress_correct, the value is TRUE if prim stress is correct (obv), FALSE if moved. 

#We do not have frequencies for the fillers and we cannot obtain ones that are comparable to the Yandex searches from 2008-9. It might be worthwhile to obtain freqs from Serge Sharoff's database, though. 

#The AE didn't ask us to compare fillers to target items, and we can't anyway, since they manipulate stress differently (sec stress is not licensed on single-root words). But I got the sense while looking through them that the ones with sed stress on the outermost prefix are nowhere near as bad as the ones with sec stress elsewhere. Might be worth checking.

##########################################################
##########################################################
##########################################################